@@ -39,6 +39,9 @@ setClass("BetaFamily",
 ## Normal location family
 setClass("NormLocationFamily",
           contains = "L2LocationFamily")
+## Cauchy location family
+setClass("CauchyLocationFamily",
+          contains = "L2LocationFamily")
 
 ## Normal scale family
 setClass("NormScaleFamily",
@@ -60,4 +63,7 @@ setClass("NormLocationScaleFamily",
 setClass("CauchyLocationScaleFamily",
           contains = "L2LocationScaleFamily")
 
+## Logistic location scale family
+setClass("LogisticLocationScaleFamily",
+          contains = "L2LocationScaleFamily")
 
