@@ -4,7 +4,8 @@
 MCEstimator <- function(x, ParamFamily, criterion, crit.name, 
                         startPar = NULL, 
                         Infos, trafo = NULL, penalty = 1e20, validity.check = TRUE,
-                        asvar.fct, na.rm = TRUE, ..., .withEvalAsVar = TRUE){
+                        asvar.fct, na.rm = TRUE, ..., .withEvalAsVar = TRUE,
+                        nmsffx = "", .with.checkEstClassForParamFamily = TRUE){
 
     ## preparation: getting the matched call
     es.call <- match.call()
@@ -33,14 +34,14 @@ MCEstimator <- function(x, ParamFamily, criterion, crit.name,
     if(missing(crit.name)) crit.name <- ""
     argList <- c(argList, crit.name = crit.name)               
     if(!is.null(dots))      argList <- c(argList, dots)
-
+#    print(argList)
 
     ## call to mceCalc
     res0 <- do.call(mceCalc, argList)
     
     asv <- if("FisherInfo" %in% slotNames(ParamFamily)){
               function(ParamFamily, param)
-                                  solve(FisherInfo(ParamFamily, param = param))
+                                  distr::solve(FisherInfo(ParamFamily, param = param))
            }else NULL
     
     argList <- c(list(res0, PFam = ParamFamily, 
@@ -53,10 +54,13 @@ MCEstimator <- function(x, ParamFamily, criterion, crit.name,
 
     if(!is.null(asv))   argList <- c(argList, asvar.fct = asv)
     if(!is.null(dots))  argList <- c(argList, dots)
+    argList <- c(argList, x = x)
+    if(any(nmsffx!="")) argList <- c(argList, nmsffx = nmsffx)
 
     ## digesting the results of mceCalc
     res <- do.call(.process.meCalcRes, argList)
     res@completecases <- completecases
-    
-    return(.checkEstClassForParamFamily(ParamFamily,res))
+    if(.with.checkEstClassForParamFamily)
+       res <- .checkEstClassForParamFamily(ParamFamily,res)
+    return(res)
 }
